==> visiscript_src_0.3.2.tar.gz: visiscript-0.3.2/main.cpp <==
/**************************************************************************
 *
 *	project				 : VisiScript
 *
 *	copyright            : (C) 2002 by Michael Neuroth
 *
 * ------------------------------------------------------------------------
 *
 *  $Source$
 *
 *  $Revision$
 *
 *	$Log$
 *
 ***************************************************************************/
/*********************************************************************************
 *																				 *
 * This file is part of the VisiScript package (a frontend for script languages) *
 *																				 *
 * Copyright (C) 2002 by Michael Neuroth.										 *
 *                                                                               *
 * This program is free software; you can redistribute it and/or modify			 *
 * it under the terms of the GNU General Public License as published by    		 *
 * the Free Software Foundation; either version 2 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 ********************************************************************************/

#include "visiscript.h"

#include <qapplication.h>
#include <qtextcodec.h>
#include <qtranslator.h>


QString ProcessLanguage( QTranslator * pTranslator, const QString & sLanguage, QApplication * qApp )
{
	// ** need global Translator for the other dialogs...
	QString sLangTemp = sLanguage;
	if( sLangTemp.length()==0 )
	{
		// if language is not given as command line argument
		// than get the actual language now...
		sLangTemp = QTextCodec::locale();
		if( sLangTemp.length()>=2 )
		{
			sLangTemp = sLangTemp.left(2);
		}
	}
	QString sLang;	// = GetMinDiaSharedDirectory().c_str();
	sLang += "wvisiscript_";
	sLang += sLangTemp;
//	sLang += "en";
	sLang += ".qm";
	if( sLangTemp != "en" )
	{
		bool bOk = pTranslator->load( sLang, "." );
		//cout << "==>> " << (const char *)sLang << " bOk=" << bOk << " " << (const char *)sLangTemp << endl;
		qApp->installTranslator( pTranslator );
	}
	return sLangTemp;
}


int main( int argc, char** argv )
{
	QApplication aAppl( argc, argv );

	// ** prepare application for different languages...**
	QTranslator * pTranslator = new QTranslator(0);
	QString sLanguage;
	QString sLanguageTemp = ProcessLanguage( pTranslator, sLanguage, &aAppl );

	VisiScript aMainwindow;
	aAppl.setMainWidget(&aMainwindow);

	aMainwindow.show();

	for( int i=1; i<argc; i++ )
	{
		aMainwindow.DoImportFile( argv[i] );
	}

	int iRet = aAppl.exec();

	delete pTranslator;

	return iRet;
}

==> visiscript_src_0.4.3.tar.gz: visiscript-0.4.3/main.cpp <==
/**************************************************************************
 *
 *	project				 : VisiScript
 *
 *	copyright            : (C) 2002 by Michael Neuroth
 *
 * ------------------------------------------------------------------------
 *
 *  $Source: E:/home/cvsroot/visiscript/main.cpp,v $
 *
 *  $Revision: 1.5 $
 *
 *	$Log: main.cpp,v $
 *	Revision 1.5  2005/12/15 08:45:20  Michael
 *	using applicationDirPath() to save application path
 *	
 *	Revision 1.4  2005/11/27 16:19:07  Michael
 *	added comment
 *	
 *	Revision 1.3  2005/11/20 16:24:30  Michael
 *	fix for the zaurus platform
 *	
 *	Revision 1.2  2005/11/12 12:09:10  Michael
 *	saving installation path from argv
 *	
 *	Revision 1.1.1.1  2005/11/06 11:34:15  Michael
 *	initial checkin of version 0.3.2
 *	
 *
 ***************************************************************************/
/*********************************************************************************
 *																				 *
 * This file is part of the VisiScript package (a frontend for script languages) *
 *																				 *
 * Copyright (C) 2002 by Michael Neuroth.										 *
 *                                                                               *
 * This program is free software; you can redistribute it and/or modify			 *
 * it under the terms of the GNU General Public License as published by    		 *
 * the Free Software Foundation; either version 2 of the License, or             *
 * (at your option) any later version.                                           *
 *                                                                               *
 ********************************************************************************/

#include "visiscript.h"

#include <qapplication.h>
#include <qdir.h>
#include <qtextcodec.h>
#include <qtranslator.h>

static QString g_strInstallationPath;

QString getInstallationPath()
{
	return g_strInstallationPath;
}

QString ProcessLanguage( QTranslator * pTranslator, const QString & sLanguage, QApplication * qApp )
{
	// ** need global Translator for the other dialogs...
	QString sLangTemp = sLanguage;
	if( sLangTemp.length()==0 )
	{
		// if language is not given as command line argument
		// than get the actual language now...
		sLangTemp = QTextCodec::locale();
		if( sLangTemp.length()>=2 )
		{
			sLangTemp = sLangTemp.left(2);
		}
	}
	QString sLang;
	sLang += "wvisiscript_";
	sLang += sLangTemp;
	sLang += ".qm";

#ifdef ZAURUS
	if( sLangTemp != "en" )
#endif
	{
		bool bOk = pTranslator->load( getInstallationPath()+sLang, "." );
		qApp->installTranslator( pTranslator );
	}
	return sLangTemp;
}

int main( int argc, char** argv )
{
	QApplication aAppl( argc, argv );

	// save the installation path of the application,
	// that is the path of the visiscript-application
	g_strInstallationPath = aAppl.applicationDirPath()+QDir::separator();

	// ** prepare application for different languages...**
	QTranslator * pTranslator = new QTranslator(0);
	QString sLanguage;
	QString sLanguageTemp = ProcessLanguage( pTranslator, sLanguage, &aAppl );

	VisiScript aMainwindow;
	aAppl.setMainWidget(&aMainwindow);

	aMainwindow.show();

	// try to load some given files
	for( int i=1; i<argc; i++ )
	{
		aMainwindow.DoImportFile( argv[i] );
	}

	int iRet = aAppl.exec();

	delete pTranslator;

	return iRet;
}
